@@ -12,22 +12,45 @@
 
 KNOWN_ATTRIBUTES = (
     'admin_state_up',
-    'id',
+    'allocation_pools',
+    'cidr',
+    'default_prefixlen',
+    'default_quota',
     'description',
+    'device_id',
+    'device_owner',
+    'dns_nameservers',
+    'enable_dhcp',
+    'fixed_ips',
+    'gateway_ip',
+    'host_routes',
+    'id',
+    'ip_version',
+    'ipv6_address_mode',
+    'ipv6_ra_mode',
+    'is_default',
+    'mac_address',
+    'max_prefixlen',
+    'min_prefixlen',
     'name',
     'network_id',
     'port_id',
+    'prefixes',
+    'prefixlen',
     'project_id',
     'shared',
     'status',
-    'tenant_id',
+    'subnets',
+    'subnetpool_id',
+    'tenant_id'
 )
 
 KNOWN_RESOURCES = (
     'networks',
     'ports',
-    'subnets',
     'routers',
+    'subnets',
+    'subnetpools'
 )
 
 KNOWN_HTTP_ACTIONS = (
@@ -37,6 +60,16 @@ KNOWN_HTTP_ACTIONS = (
     'PUT',
 )
 
+KNOWN_ACTION_STATUSES = (
+    200,
+    201,
+    202,
+    203,
+    204,
+    205,
+    206,
+)
+
 KNOWN_EXTENSIONS = (
     'address-scope',
     'agent',
@@ -44,8 +77,10 @@ KNOWN_EXTENSIONS = (
     'auto-allocated-topology',
     'availability_zone',
     'binding',
+    'data-plane-status',
     'default-subnetpools',
     'dhcp_agent_scheduler',
+    'dns-domain-ports',
     'dns-integration',
     'dvr',
     'ext-gw-mode',
@@ -55,6 +90,7 @@ KNOWN_EXTENSIONS = (
     'flavors',
     'l3-ha',
     'l3_agent_scheduler',
+    'logging',
     'metering',
     'multi-provider',
     'net-mtu',
@@ -81,23 +117,15 @@ KNOWN_EXTENSIONS = (
     'trunk-details',
     # Add here list of extensions with pointers to the project repo, e.g.
     # 'bgp',  # http://git.openstack.org/cgit/openstack/neutron-dynamic-routing
-    'fw',  # http://git.openstack.org/cgit/openstack/neutron-fwaas
-    'fwaas',  # http://git.openstack.org/cgit/openstack/neutron-fwaas
+
+    # http://git.openstack.org/cgit/openstack/neutron-fwaas
+    'fwaas',
+    'fwaasrouterinsertion',
+    'fwaas_v2',
+    'bgpvpn',  # https://git.openstack.org/cgit/openstack/networking-bgpvpn
+    'bgpvpn-routes-control',
 )
 
-# The following is a short reference for understanding attribute info:
-# allow_post: the attribute can be used on POST requests.
-# allow_put: the attribute can be used on PUT requests.
-# convert_to: transformation to apply to the value before it is returned
-# default: default value of the attribute (if missing, the attribute
-# becomes mandatory.
-# enforce_policy: the attribute is actively part of the policy enforcing
-# mechanism, ie: there might be rules which refer to this attribute.
-# is_visible: the attribute is returned in GET responses.
-# required_by_policy: the attribute is required by the policy engine and
-# should therefore be filled by the API layer even if not present in
-# request body.
-# validate: specifies rules for validating data in the attribute.
 KNOWN_KEYWORDS = (
     'allow_post',
     'allow_put',
